"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.enableHoverInfo = exports.disableHoverInfo = exports.hoverInfoEnabled = exports.removeHoverInfo = exports.showHoverInfo = void 0;
const tooltip_1 = require("../ui/tooltip");
const conversions_1 = require("../utils/conversions");
const states = new WeakMap();
/**
 * Show hover information.
 * @param editor
 * @param mouseLeaveAllListener
 * @param pos Position of the event
 * @param hover
 * @param renderMarkdown
 */
const showHoverInfo = (editor, mouseLeaveAllListener, pos, hover, renderMarkdown = (x) => x) => {
    (0, exports.removeHoverInfo)(editor);
    if (Array.isArray(hover.contents) && hover.contents.length === 0)
        return;
    const info = (0, conversions_1.hoverContentsToString)(hover.contents, renderMarkdown);
    if (!info)
        return;
    const state = states.get(editor) || {};
    let start = pos;
    if (hover.range) {
        let end = pos;
        [start, end] = (0, conversions_1.cmRange)(hover.range);
        state.marker = editor.markText(start, end, {
            css: "text-decoration: underline",
        });
    }
    const el = document.createElement("div");
    el.innerHTML = info;
    const coords = editor.charCoords(start, "page");
    state.tooltip = (0, tooltip_1.addTooltip)(el, coords.left, coords.top);
    state.mouseLeaveAllListener = mouseLeaveAllListener;
    mouseLeaveAllListener.addElement(state.tooltip);
    states.set(editor, state);
};
exports.showHoverInfo = showHoverInfo;
/**
 * Remove hover information from the editor.
 * @param editor
 */
const removeHoverInfo = (editor) => {
    const state = states.get(editor);
    if (!state)
        return;
    if (state.marker)
        state.marker.clear();
    if (state.mouseLeaveAllListener && state.tooltip)
        state.mouseLeaveAllListener.removeElement(state.tooltip);
    if (state.tooltip)
        state.tooltip.remove();
    states.delete(editor);
};
exports.removeHoverInfo = removeHoverInfo;
const hoverInfoEnabled = (editor) => { var _a; return !((_a = states.get(editor)) === null || _a === void 0 ? void 0 : _a.disabled); };
exports.hoverInfoEnabled = hoverInfoEnabled;
const disableHoverInfo = (editor) => {
    (0, exports.removeHoverInfo)(editor);
    states.set(editor, { disabled: true });
};
exports.disableHoverInfo = disableHoverInfo;
const enableHoverInfo = (editor) => {
    (0, exports.removeHoverInfo)(editor);
};
exports.enableHoverInfo = enableHoverInfo;
//# sourceMappingURL=hover.js.map